summaryrefslogtreecommitdiffstats
path: root/lib/qextfileinfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/qextfileinfo.h')
-rw-r--r--lib/qextfileinfo.h35
1 files changed, 18 insertions, 17 deletions
diff --git a/lib/qextfileinfo.h b/lib/qextfileinfo.h
index 96d418fb..ca51123b 100644
--- a/lib/qextfileinfo.h
+++ b/lib/qextfileinfo.h
@@ -9,8 +9,8 @@
(at your option) any later version.
*/
-#ifndef _QEXTFILEINFO_H_
-#define _QEXTFILEINFO_H_
+#ifndef _TQEXTFILEINFO_H_
+#define _TQEXTFILEINFO_H_
#include <kio/global.h>
#include <kio/job.h>
@@ -22,12 +22,13 @@
#include <tqdict.h>
#include <tqregexp.h>
-class QExtFileInfo:public QObject
+class TQExtFileInfo:public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- QExtFileInfo() {};
- ~QExtFileInfo() {};
+ TQExtFileInfo() {};
+ ~TQExtFileInfo() {};
/**
* Works like TQDir::canonicalPath, but it does not return an empty
@@ -37,7 +38,7 @@ public:
* Example:
* /home/user/foo points to /mnt/foo
* /home/user/foo/foo2 does not exists
* QExtFileInfo::canonicalPath("/home/user/foo/foo2/") will return
* /mnt/foo/foo2/ .
* @param path the path to resolve
* @return the canonical path (symlinks resolved)
@@ -54,21 +55,21 @@ public:
static KURL toRelative(const KURL& urlToConvert, const KURL& baseURL, bool resolveSymlinks = true);
/** Convert relative url to absolute, based on baseURL. */
static KURL toAbsolute(const KURL& urlToConvert, const KURL& baseURL);
- /** Returns a recursive list of files under path, matching the specified file mask. */
- static KURL::List allFiles( const KURL& path, const TQString &mask, TQWidget *window);
- /** Returns a recursive list of files under path, matching the specified file mask.
+ /** Returns a recursive list of files under path, matching the specified file tqmask. */
+ static KURL::List allFiles( const KURL& path, const TQString &tqmask, TQWidget *window);
+ /** Returns a recursive list of files under path, matching the specified file tqmask.
The returned urls are relative to path.
*/
- static KURL::List allFilesRelative( const KURL& path, const TQString &mask, TQWidget *window, bool resolveSymlinks = true);
- /** Returns a recursive list of files under path, matching the specified file mask.
+ static KURL::List allFilesRelative( const KURL& path, const TQString &tqmask, TQWidget *window, bool resolveSymlinks = true);
+ /** Returns a recursive list of files under path, matching the specified file tqmask.
The returned list contains detailed information about each url.
The user should delete the KFileItems and clear the dict
after they are not needed.
*/
- static TQDict<KFileItem> allFilesDetailed(const KURL& path, const TQString &mask, TQWidget *window);
+ static TQDict<KFileItem> allFilesDetailed(const KURL& path, const TQString &tqmask, TQWidget *window);
/** Creates a dir if don't exists. */
static bool createDir(const KURL & path, TQWidget *window);
- /** Returns the parent directory of dir. */
+ /** Returns the tqparent directory of dir. */
static KURL cdUp(const KURL &dir);
/** Returns the filename from a path string. */
static TQString shortName(const TQString &fname );
@@ -83,7 +84,7 @@ public:
/** Synchronous copy, like NetAccess::file_copy in KDE 3.2, just that it doesn't show a progress dialog */
static bool copy( const KURL& src, const KURL& dest, int permissions=-1,
bool overwrite=false, bool resume=false, TQWidget* window = 0L );
- /** Reenters the event loop. You must call qApp->exit_loop() to exit it. */
+ /** Reenters the event loop. You must call tqApp->exit_loop() to exit it. */
void enter_loop();
private:
@@ -92,9 +93,9 @@ private:
bool internalExists(const KURL& url, bool readingOnly, TQWidget *window);
bool internalCopy(const KURL& src, const KURL& target, int permissions,
bool overwrite, bool resume, TQWidget* window);
- KURL::List allFilesInternal(const KURL& startURL, const TQString& mask, TQWidget *window);
- TQDict<KFileItem> allFilesDetailedInternal(const KURL& startURL, const TQString& mask, TQWidget *window);
- KURL::List allLocalFiles(const TQString& startPath, const TQString& mask);
+ KURL::List allFilesInternal(const KURL& startURL, const TQString& tqmask, TQWidget *window);
+ TQDict<KFileItem> allFilesDetailedInternal(const KURL& startURL, const TQString& tqmask, TQWidget *window);
+ KURL::List allLocalFiles(const TQString& startPath, const TQString& tqmask);
bool bJobOK;
static TQString lastErrorMsg;
@@ -37,7 +38,7 @@ public:
* /home/user/foo points to /mnt/foo
* /home/user/foo/foo2 does not exists
- * QExtFileInfo::canonicalPath("/home/user/foo/foo2/") will return
+ * TQExtFileInfo::canonicalPath("/home/user/foo/foo2/") will return
* /mnt/foo/foo2/ .
* @param path the path to resolve